@@ -9,11 +9,14 @@ class OTPEmailSettings:
     values if they are not specified by the configuration.
 
     """
+
     defaults = {
         'OTP_EMAIL_SENDER': None,
         'OTP_EMAIL_SUBJECT': 'OTP token',
         'OTP_EMAIL_BODY_TEMPLATE': None,
         'OTP_EMAIL_BODY_TEMPLATE_PATH': 'otp/email/token.txt',
+        'OTP_EMAIL_BODY_HTML_TEMPLATE': None,
+        'OTP_EMAIL_BODY_HTML_TEMPLATE_PATH': None,
         'OTP_EMAIL_TOKEN_VALIDITY': 300,
         'OTP_EMAIL_THROTTLE_FACTOR': 1,
     }
